@@ -28,13 +28,15 @@ ESCAPE = b'\x1c'
 RASPBERRY_PI = '/dev/ttyAMA0'
 
 class VFD(object):
-    def __init__(self, serial_path):
+    def __init__(self, serial_path, clear=False):
         self.serial = serial.Serial(serial_path, baudrate=9600, timeout=1)
         self._cursor = 'off'
         self._cursor_type = 'underline'
         self.serial.write(CURSOR[self._cursor])
         self.serial.write(CURSOR_TYPE[self._cursor_type])
-        self.clear()
+        if clear:
+            self.clear()
+        self.write(CR)
 
     @property
     def cursor(self):
